// Single colour highlight effect
//  Copyright (c) 2013 Open Planet Software. All rights reserved.


varying vec2 texCoordVarying;

uniform sampler2D sourceImage;
uniform vec4 inputs;
uniform vec4 splashColour;

void main()
{
    float threshold = inputs.x;
    float smoothing = inputs.y;
    float cutoff = inputs.z;
        
    vec4 textureColor = texture2D(sourceImage, texCoordVarying);

    float maskY = 0.2989 * splashColour.r + 0.5866 * splashColour.g + 0.1145 * splashColour.b;
    float maskCr = 0.7132 * (splashColour.r - maskY);
    float maskCb = 0.5647 * (splashColour.b - maskY);
    
    float Y = 0.2989 * textureColor.r + 0.5866 * textureColor.g + 0.1145 * textureColor.b;
    float Cr = 0.7132 * (textureColor.r - Y);
    float Cb = 0.5647 * (textureColor.b - Y);
    
    float blendValue = smoothstep(threshold, threshold + smoothing, distance(vec2(Cr, Cb), vec2(maskCr, maskCb)));
    
    blendValue = step( 0.05, blendValue );
    
    float luminance = textureColor.r * 0.299 + textureColor.g * 0.587 + textureColor.b * 0.114;

    gl_FragColor = vec4( luminance * blendValue + (textureColor.x * (1.0 - blendValue)),
    luminance * blendValue + (textureColor.y * (1.0 - blendValue)),
    luminance * blendValue + (textureColor.z * (1.0 - blendValue)), 1.0 );
    
}
